@@ -115,8 +115,11 @@ class BibList(dict):
       return False
 
     if key in self.ListItems:
-      sys.stderr.write('W: ENTRY ALREADY PRESENT: %s (%s)\n'%(key,bib['_code']))
-      return False
+      if key == self.get_item(key).get_field('_code'): 
+        sys.stderr.write('W: ENTRY ALREADY PRESENT: %s (%s)\n'%(key,bib['_code']))
+        return False
+      else:
+        key = be.get_field('_code')
 
     self.bib[key]= be
     self.ListItems.append(key)
@@ -267,20 +270,17 @@ class BibList(dict):
     if st != []:
       for k,v in st.iteritems():
         self.insertAbbrev(k, v)
-#     st.update(dict(helper.standard_abbrev))
 
+    self.keepAbbrevs = not ReplaceAbbrevs
     if db != None:
       for k,v in db.iteritems():
-        b1= bibitem.BibItem(bibitem.bibparse.replace_abbrevs(self.abbrevDict,dict(v)))
-        key= b1.get_key()
-        self.keepAbbrevs = not ReplaceAbbrevs
+        b1= bibitem.BibItem(bibitem.bibparse.replace_abbrevs(self.abbrevDict,dict(v)), normalize = normalize)
+        key= b1.get_key()               # The key is generated
         if self.keepAbbrevs:  status= self.add_item(v, key)
         else:                 status= self.add_item(b1,key)
         if status:
           ncount+= 1
-          if normalize:
-            self.get_item(key).normalize()
-
+          if normalize:   self.get_item(key).normalize() # _code is put equal to key
     self.sort()
     return ncount
 
